==> foundation-ui-components-1.25.1-cx130-1205.1.tgz: package/src/common/accordion/NsAccordionHeader.tsx <==
import { styled } from '@nuskin/foundation-theme';

import {
    AccordionVariant,
    AccordionVariantType,
    NsAccordionHeaderProps,
    NsIcon,
    NsIconProps,
    NsTypography,
} from '../';
import { isValidIconName } from '../icon/NsIconVariants';
import { getAccordionColor } from './colorMap';

type StyledType = { variant: AccordionVariantType; invert: boolean };

const StyledHeader = styled('header')<StyledType>(({ theme, variant, invert }) => {
    const { headBg, headText } = getAccordionColor({ theme, variant, invert, keys: ['headBg', 'headText'] });
    let borderBottom = 'none';
    if (variant === AccordionVariant.Compact) {
        borderBottom = '1px solid rgb(0,0,0,0.125)';
    }
    return {
        backgroundColor: headBg,
        color: headText,
        cursor: 'pointer',
        display: 'grid',
        gap: '4px',
        gridTemplateColumns: 'auto 1fr 24px',
        padding: '9px 16px',
        borderBottom,
        '.nsa-item-title': {
            color: headText,
        },
    } as any;
});

/**
 * NsAccordionHeader is primarily used by NsToggleSection and NsAccordionItem
 * as a header, so it accepts `title` , `isOpen` and `onClick`
 */
const NsAccordionHeader = ({
    title,
    onClick,
    isOpen,
    additionalProps,
    openedIconName,
    closedIconName,
    variant,
    headerTypographyVariant,
    startIcon,
    invert,
    cslp,
    showEndIconWhenEmpty,
    content,
}: NsAccordionHeaderProps) => {
    return (
        <StyledHeader
            invert={invert}
            role="button"
            aria-expanded={isOpen ? 'true' : 'false'}
            className={`section-header ${isOpen ? 'expanded' : ''} ${additionalProps?.className ?? ''}`}
            onClick={onClick}
            variant={variant}
        >
            <HeaderIcon {...startIcon} />
            {typeof title === 'string' ? (
                <NsTypography variant={headerTypographyVariant ?? 'h4'} weight="bold" {...(cslp?.header ?? {})}>
                    {title}
                </NsTypography>
            ) : (
                title
            )}
            {content || showEndIconWhenEmpty ? (
                <span className="header-icon">
                    <NsIcon name={isOpen ? openedIconName ?? 'arrowUp' : closedIconName ?? 'arrowDown'} />
                </span>
            ) : null}
        </StyledHeader>
    );
};
export default NsAccordionHeader;

const HeaderIcon = (props: Partial<NsIconProps>) => {
    const hasIcon = props?.name ? isValidIconName(props?.name) : false;
    if (!hasIcon) return <span />;
    return <NsIcon {...(props as NsIconProps)} />;
};

==> foundation-ui-components-1.29.1-cx130-1299.2.tgz: package/src/common/accordion/NsAccordionHeader.tsx <==
import { ReactNode } from 'react';

import { styled } from '@nuskin/foundation-theme';

import {
    AccordionVariant,
    AccordionVariantType,
    NsAccordionHeaderProps,
    NsIcon,
    NsIconProps,
    NsTypography,
} from '../';
import { isValidIconName } from '../icon/NsIconVariants';
import { getAccordionColor } from './colorMap';

type StyledType = { variant: AccordionVariantType; invert: boolean };

const StyledHeader = styled('header')<StyledType>(({ theme, variant, invert }) => {
    const { headBg, headText } = getAccordionColor({ theme, variant, invert, keys: ['headBg', 'headText'] });
    let borderBottom = 'none';
    if (variant === AccordionVariant.Compact) {
        borderBottom = '1px solid rgb(0,0,0,0.125)';
    }
    return {
        backgroundColor: headBg,
        color: headText,
        cursor: 'pointer',
        display: 'grid',
        gap: '4px',
        gridTemplateColumns: 'auto 1fr 24px',
        padding: '9px 16px',
        borderBottom,
        '.nsa-item-title': {
            color: headText,
        },
    } as any;
});

/**
 * NsAccordionHeader is primarily used by NsToggleSection and NsAccordionItem
 * as a header, so it accepts `title` , `isOpen` and `onClick`
 */
const NsAccordionHeader = ({
    title,
    onClick,
    isOpen,
    additionalProps,
    openedIconName,
    closedIconName,
    variant,
    headerTypographyVariant,
    startIcon,
    invert,
    cslp,
    showEndIconWhenEmpty,
    content,
}: NsAccordionHeaderProps) => {
    return (
        <StyledHeader
            invert={invert}
            role="button"
            aria-expanded={isOpen ? 'true' : 'false'}
            className={`section-header ${isOpen ? 'expanded' : ''} ${additionalProps?.className ?? ''}`}
            onClick={onClick}
            variant={variant}
        >
            <HeaderIcon {...startIcon} invert={invert} />
            {typeof title === 'string' ? (
                <NsTypography variant={headerTypographyVariant ?? 'h4'} weight="bold" {...(cslp?.header ?? {})}>
                    {title}
                </NsTypography>
            ) : (
                title
            )}
            {content || showEndIconWhenEmpty ? (
                <span className="header-icon">
                    <NsIcon
                        {...(invert ? { color: 'secondary' } : {})}
                        name={isOpen ? openedIconName ?? 'arrowUp' : closedIconName ?? 'arrowDown'}
                    />
                </span>
            ) : null}
        </StyledHeader>
    );
};
export default NsAccordionHeader;

const HeaderIcon = (props: Partial<NsIconProps> & { invert: boolean }): ReactNode => {
    const hasIcon = props?.name ? isValidIconName(props?.name) : false;
    if (!hasIcon) return (<span />) as any;
    return <NsIcon {...(props as NsIconProps)} {...(props.invert ? { color: 'secondary' } : {})} />;
};
